"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RedisClientWrapper = void 0;
const constans_1 = require("./constans");
class RedisWrapper {
    constructor(client) {
        this.client = client;
    }
    del(...keys) {
        return new Promise((resolve, reject) => {
            this.client.del(keys, (err, data) => {
                if (err) {
                    return reject(err);
                }
                return resolve(data);
            });
        });
    }
    get(key) {
        return new Promise((resolve, reject) => {
            this.client.get(key, (err, data) => {
                if (err) {
                    return reject(err);
                }
                return resolve(data);
            });
        });
    }
    keys(key) {
        return new Promise((resolve, reject) => {
            this.client.keys(key, (err, data) => {
                if (err) {
                    return reject(err);
                }
                return resolve(data);
            });
        });
    }
    set(key, value, opts) {
        return new Promise((resolve, reject) => {
            this.client.set(key, value, 'EX', opts.EX, (err) => {
                if (err) {
                    return reject(err);
                }
                return resolve();
            });
        });
    }
}
class IORedisWrapper {
    constructor(client) {
        this.client = client;
    }
    del(...keys) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield this.client.del(...keys);
            }
            catch (err) {
                console.log('===err del', err);
            }
            return 0;
        });
    }
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield this.client.get(key);
            }
            catch (err) {
                console.log('===err get', err);
            }
            return null;
        });
    }
    keys(key) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const k = yield this.client.keys(key);
                console.log('===k', k);
                return k;
            }
            catch (err) {
                console.log('===err keys', err);
            }
            return [];
        });
    }
    set(key, value, opts) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield this.client.set(key, value, 'EX', opts.EX);
            }
            catch (err) {
                console.log('===err set', err);
            }
        });
    }
}
// add other wrapper
class RedisClientWrapper {
    constructor(packageName, client) {
        if (!client) {
            throw new Error('redis client is required');
        }
        if (packageName === constans_1.REDIS_PACKAGE.REDIS) {
            this.clientWrapper = new RedisWrapper(client);
        }
        else if (packageName === constans_1.REDIS_PACKAGE.IOREDIS) {
            this.clientWrapper = new IORedisWrapper(client);
        }
        else {
            throw new Error('redis client only support from packages: redis, ioredis');
        }
    }
    getWrapper() {
        return this.clientWrapper;
    }
}
exports.RedisClientWrapper = RedisClientWrapper;
